from setuptools import setup

from setuptools_rust import Binding, RustExtension

setup(
    name="hello-world",
    version="1.0",
    rust_extensions=[
        RustExtension(
            {"hello-world": "hello_world.hello-world"},
            binding=Binding.Exec,
            script=True,
            args=["--profile", "release-lto"],
        )
    ],
    # rust extensions are not zip safe, just like C-extensions.
    zip_safe=False,
)



from setuptools import setup, find_namespace_packages
from setuptools_rust import Binding, RustExtension


setup(
    name="namespace_package",
    version="0.1.0",
    packages=find_namespace_packages(include=["namespace_package.*"]),
    zip_safe=False,
    rust_extensions=[
        RustExtension(
            "namespace_package.rust",
            path="Cargo.toml",
            binding=Binding.PyO3,
            debug=False,
        )
    ],
)



from os.path import dirname

import nox

SETUPTOOLS_RUST = dirname(dirname(dirname(__file__)))


@nox.session()
def test(session: nox.Session):
    session.install(SETUPTOOLS_RUST)
    session.install(".")
    session.run("hello-world", *session.posargs)



import os
import tarfile
from glob import glob
from pathlib import Path

import nox


@nox.session(name="test-examples", venv_backend="none")
def test_examples(session: nox.Session):
    for example in glob("examples/*/noxfile.py"):
        session.run("nox", "-f", example, external=True)


@nox.session(name="test-sdist-vendor")
def test_sdist_vendor(session: nox.Session):
    session.install(".")
    namespace_package = Path(__file__).parent / "examples" / "namespace_package"
    os.chdir(namespace_package)
    session.run("python", "setup.py", "sdist", "--vendor-crates", external=True)
    dist = namespace_package / "dist"
    with tarfile.open(str(dist / "namespace_package-0.1.0.tar.gz")) as tf:
        tf.extractall(str(dist))
    os.chdir(dist / "namespace_package-0.1.0")
    session.run("cargo", "build", "--offline", external=True)


@nox.session()
def mypy(session: nox.Session):
    session.install("mypy", "fat_macho", "types-setuptools", ".")
    session.run("mypy", "setuptools_rust", *session.posargs)


@nox.session()
def test(session: nox.Session):
    session.install("pytest", ".")
    session.run("pytest", "setuptools_rust", *session.posargs)
